| Title: | Forward Stepwise Deep Autoencoder-Based Monotone NLDR |
|---|---|
| Description: | FS-DAM performs feature extraction through latent variables identification. Implementation is based on autoencoders with monotonicity and orthogonality constraints. |
| Authors: | Youyi Fong [cre], Jun Xu [aut] |
| Maintainer: | Youyi Fong <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 2024.7-30 |
| Built: | 2026-05-11 08:08:13 UTC |
| Source: | https://github.com/youyifong/fsdam |
See reference.
data("cc.505")data("cc.505")
A data frame with 189 observations on the following 27 variables.
ptida character vector
trta numeric vector
casea numeric vector
controla numeric vector
perprota numeric vector
last_uninfec_immun_vsta numeric vector
racefulla numeric vector
racefulltxta character vector
bmia numeric vector
bmicata numeric vector
bmicattxta character vector
earliest_pos_vsta numeric vector
levela character vector
matchlevela character vector
samplingfractiona numeric vector
vst9subcohorta numeric vector
HIVwk28preunbla numeric vector
agea numeric vector
racecca character vector
bhvriska numeric vector
BMIa numeric vector
stratuminds_vaccsa numeric vector
stratumindsa numeric vector
cd4.env.polya numeric vector
cd8.env.polya numeric vector
mfoundersa numeric vector
weia numeric vector
Fong, Y, Xu, J. Multi-Stage Simultaneous Deep Autoencoder-based Monotone (MSS-DAM) Nonlinear Dimensionality Reduction Methods, Journal of Computational and Graphical Statistics, in press.
Forward stepwise deep autoencoder-based monotone nonlinear dimension reduction.
fsdam(dat, opt_numCode = ncol(dat), opt_seed = 1, opt_model = "n", opt_gpu = 0, opt_k = 100, opt_nEpochs = 10000, opt_constr = c("newpenalization", "constrained", "none"), opt_tuneParam = 10, opt_penfun = "mean", opt_ortho = 1, opt_earlystop = "no", verbose = FALSE) ## S3 method for class 'fsdam' plot(x, which=c("mse", "history", "decoder.func", "scatterplot"), k=NULL, dim.1=NULL, dim.2=NULL, col.predict=2, ...)fsdam(dat, opt_numCode = ncol(dat), opt_seed = 1, opt_model = "n", opt_gpu = 0, opt_k = 100, opt_nEpochs = 10000, opt_constr = c("newpenalization", "constrained", "none"), opt_tuneParam = 10, opt_penfun = "mean", opt_ortho = 1, opt_earlystop = "no", verbose = FALSE) ## S3 method for class 'fsdam' plot(x, which=c("mse", "history", "decoder.func", "scatterplot"), k=NULL, dim.1=NULL, dim.2=NULL, col.predict=2, ...)
dat |
data frame. |
opt_numCode |
number of components to extract |
opt_seed |
seed for torch |
opt_model |
n for newpenalization |
opt_gpu |
zero-based index of gpu to be used among all gpus. If negative, then no gpu is used |
opt_k |
number of nodes in the coding/decoding layers |
opt_nEpochs |
number of epochs for training |
opt_constr |
constraint string |
opt_tuneParam |
tuning parameter for monotonicity penalty |
opt_penfun |
penalize sum or mean |
opt_ortho |
tuning parameter for orthogonality penalty |
opt_earlystop |
whether to stop early |
verbose |
verbose |
x |
fsdam object |
which |
which |
k |
the component to plot |
dim.1 |
index of the first variable |
dim.2 |
index of the second variable |
col.predict |
color of the predicted curve when which = scatterplot |
... |
plotting arguments |
If using the default reticulate python virtual env, may need to install some python packages via: reticulate::py_install("torch", pip = TRUE) reticulate::py_install("numpy", pip = TRUE) reticulate::py_install("pandas", pip = TRUE)
Alternatively, use a different python kernel by
reticulate::use_python("/app/easybuild/software/Python/3.7.4-foss-2016b/bin/python")
It is recommended that dat is scaled before calling fsdam.
Fong, Y, Xu, J. Multi-Stage Simultaneous Deep Autoencoder-based Monotone (MSS-DAM) Nonlinear Dimensionality Reduction Methods, Journal of Computational and Graphical Statistics, in press.
## Not run: fit=fsdam(hvtn505tier1[1:100,-1], opt_numCode=2, verbose=TRUE) fit plot(fit,which="mse") plot(fit,which="history") ## End(Not run)## Not run: fit=fsdam(hvtn505tier1[1:100,-1], opt_numCode=2, verbose=TRUE) fit plot(fit,which="mse") plot(fit,which="history") ## End(Not run)
Contains eight immune response variables from the vaccine arm of the HVTN 505 trial.
data("hvtn505tier1")data("hvtn505tier1")
A data frame with 150 observations on the following 9 variables.
ptida character vector
CD8_ANYVRCENV_PolyfunctionalityScore_scorea numeric vector
IgGw28_env_mdwa numeric vector
IgGw28_V1V2_mdwa numeric vector
IgGw28_gp41_mdwa numeric vector
ADCP1a numeric vector
R2aConSgp140CFIa numeric vector
IgAw28_env_mdwa numeric vector
IgG3w28_env_mdwa numeric vector
Fong, Y, Xu, J. Multi-Stage Simultaneous Deep Autoencoder-based Monotone (MSS-DAM) Nonlinear Dimensionality Reduction Methods, Journal of Computational and Graphical Statistics, in press.
Janes, H.E., Cohen, K.W., Frahm, N., De Rosa, S.C., Sanchez, B., Hural, J. et al (2017), Higher T-cell responses induced by DNA/rAd5 HIV-1 preventive vaccine are associated with lower HIV-1 infection risk in an efficacy trial, The Journal of infectious diseases, 215, 1376-1385.
Fong, Y., Shen, X., Ashley, V.C., Deal, A., Seaton, K.E., Yu, C. et al (2018), Vaccine-induced antibody responses modify the association between T-cell immune responses and HIV-1 infection risk in HVTN 505, The Journal of Infectious Diseases, 217, 1280–1288.
Neidich, S.D., Fong, Y., Shen, X., Ashley, V.C., Deal, A., Seaton, K.E. et al (2019), Antibody Fc-effector Functions and IgG3 Associates with Decreased HIV-1 Acquisition Risk, The Journal of Infectious Diseases, 129, 4838-4849.